@@ -7,6 +7,10 @@
  * Contract with IBM Corp.
  *******************************************************************************/
 /* Copyright (c) 2020 Red Hat, Inc. */
+/* Copyright Contributors to the Open Cluster Management project */
+
+process.env.TZ = 'UTC'
+
 const tapReporter = [
   'jest-tap-reporter',
   {
@@ -32,12 +36,13 @@ const jestConfig = {
   ],
   testResultsProcessor: 'jest-sonar-reporter',
   testURL: 'http://localhost/',
+  testEnvironment: 'jsdom',
   coverageThreshold: {
     global: {
-      branches: 55,
-      functions: 59,
-      lines: 60,
-      statements: 60,
+      branches: 50,
+      functions: 50,
+      lines: 55,
+      statements: 55,
     },
   },
   testMatch: [
@@ -49,14 +54,14 @@ const jestConfig = {
     '^.+\\.js$': 'babel-jest',
     '.+\\.(hbs)$': 'jest-handlebars',
     '.+\\.(handlebars)$': 'jest-handlebars',
-    '.+\\.(yaml)$': 'jest-yaml-transform'
+    '.+\\.(yaml)$': 'jest-yaml-transform',
   },
   globalSetup: '<rootDir>/tests/jest/config/properties-to-json.js',
   setupFiles: [
-    '<rootDir>/tests/jest/config/setup.js'
+    '<rootDir>/tests/jest/config/setup.js',
   ],
   moduleNameMapper: {
-    '\\.(css|scss|svg)$': '<rootDir>/tests/jest/config/styleMock.js',
+    '\\.(css|scss|svg|png)$': '<rootDir>/tests/jest/config/styleMock.js',
     'monaco-editor': '<rootDir>/node_modules/react-monaco-editor'
   }
 }
